package
Version:
v0.0.0-...-49d7a06
Opens a new window with list of versions in this module.
Published: Nov 27, 2023
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Adapter struct {
ReqCounter uint64
SampleCounter uint64
}
func (*Adapter) Handler ¶
Handler counts number of requests and samples
Start starts no-op Prometheus adapter. This call will block go-routine
Source Files
¶
Click to show internal directories.
Click to hide internal directories.